
From: Mikael Pettersson <mikpe@csd.uu.se>

The inclusion of the pselect6 and ppoll syscalls in 2.6.12-mm2 broke ia32
emulation on x86_64, and ppc32 emulation on ppc64, for the perfctr
syscalls.  This patch fixes this, and also corrects a few comments in the
ppc32 syscall tables.

Signed-off-by: Mikael Pettersson <mikpe@csd.uu.se>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/ppc64/kernel/misc.S         |    4 ++++
 arch/x86_64/ia32/ia32entry.S     |    2 ++
 include/asm-x86_64/ia32_unistd.h |    4 ++--
 ppc/kernel/misc.S                |    0 
 4 files changed, 8 insertions(+), 2 deletions(-)

diff -puN arch/ppc64/kernel/misc.S~perfctr-syscall-numbering-fixups arch/ppc64/kernel/misc.S
--- 25/arch/ppc64/kernel/misc.S~perfctr-syscall-numbering-fixups	Wed Jul  6 14:03:47 2005
+++ 25-akpm/arch/ppc64/kernel/misc.S	Wed Jul  6 14:04:53 2005
@@ -1131,6 +1131,10 @@ _GLOBAL(sys_call_table32)
 	.llong .sys32_ioprio_get
 	.llong .compat_sys_pselect6	/* 275 */
 	.llong .compat_sys_ppoll
+	.llong .sys_vperfctr_open
+	.llong .sys_vperfctr_control
+	.llong .sys_vperfctr_write
+	.llong .sys_vperfctr_read	/* 280 */
 
 	.balign 8
 _GLOBAL(sys_call_table)
diff -puN arch/ppc/kernel/misc.S~perfctr-syscall-numbering-fixups arch/ppc/kernel/misc.S
diff -puN arch/x86_64/ia32/ia32entry.S~perfctr-syscall-numbering-fixups arch/x86_64/ia32/ia32entry.S
--- 25/arch/x86_64/ia32/ia32entry.S~perfctr-syscall-numbering-fixups	Wed Jul  6 14:03:48 2005
+++ 25-akpm/arch/x86_64/ia32/ia32entry.S	Wed Jul  6 14:03:48 2005
@@ -588,6 +588,8 @@ ia32_sys_call_table:
 	.quad sys_keyctl
 	.quad quiet_ni_syscall		/* sys_ioprio_set */
 	.quad quiet_ni_syscall		/* sys_ioprio_get */	/* 290 */
+	.quad quiet_ni_syscall		/* pselect6 */
+	.quad quiet_ni_syscall		/* ppoll */
 	.quad sys_vperfctr_open
 	.quad sys_vperfctr_control
 	.quad sys_vperfctr_write
diff -puN include/asm-x86_64/ia32_unistd.h~perfctr-syscall-numbering-fixups include/asm-x86_64/ia32_unistd.h
--- 25/include/asm-x86_64/ia32_unistd.h~perfctr-syscall-numbering-fixups	Wed Jul  6 14:03:48 2005
+++ 25-akpm/include/asm-x86_64/ia32_unistd.h	Wed Jul  6 14:03:48 2005
@@ -294,11 +294,11 @@
 #define __NR_ia32_add_key		286
 #define __NR_ia32_request_key	287
 #define __NR_ia32_keyctl		288
-#define __NR_ia32_vperfctr_open		291
+#define __NR_ia32_vperfctr_open		293
 #define __NR_ia32_vperfctr_control	(__NR_ia32_vperfctr_open+1)
 #define __NR_ia32_vperfctr_write	(__NR_ia32_vperfctr_open+2)
 #define __NR_ia32_vperfctr_read		(__NR_ia32_vperfctr_open+3)
 
-#define IA32_NR_syscalls 295	/* must be > than biggest syscall! */
+#define IA32_NR_syscalls 297	/* must be > than biggest syscall! */
 
 #endif /* _ASM_X86_64_IA32_UNISTD_H_ */
_
